@@ -90,28 +90,20 @@ namespace ssr
 namespace internal
 {
 
-/// self-explanatory
 inline void print_about_message()
 {
   const std::string about_string =
     "       ___     \n"
     "      /  ___   \n"
     "  ___/  /  ___ \n"
-    "    ___/  /    " PACKAGE_NAME " version " PACKAGE_VERSION "\n"
+    "    ___/  /    " PACKAGE_STRING "\n"
     "         /     \n"
     "               \n"
-    " Copyright (c) 2012-2014 Institut für Nachrichtentechnik, "
-                                                         "Universität Rostock\n"
-    " Copyright (c) 2006-2012 Quality & Usability Lab\n"
-    "                         Deutsche Telekom Laboratories, TU Berlin\n"
+    "Website: <" PACKAGE_URL ">\n"
+    "Contact: <" PACKAGE_BUGREPORT ">\n"
     "\n"
-    " Website: " PACKAGE_URL "\n"
-    " Contact: " PACKAGE_BUGREPORT "\n"
-    "\n"
-    " This program comes with ABSOLUTELY NO WARRANTY;"
-    " this is free software,\n"
-    " and you are welcome to redistribute it under certain conditions;\n"
-    " for details, see the enclosed file COPYING.\n";
+    SSR_COPYRIGHT
+    ;
 
   std::cout << about_string << std::endl;
 }
@@ -257,8 +249,6 @@ class Controller : public Publisher
 #endif
     std::unique_ptr<Tracker> _tracker;
 
-    float _stand_ampl_ref_dist;
-
     /// check if audio player is running and start it if necessary
     bool _audio_player_is_running();
 
@@ -838,7 +828,8 @@ Controller<Renderer>::load_scene(const std::string& scene_file_name)
 
     // GET AMPLITUDE REFERENCE DISTANCE
 
-    float ref_dist = _conf.stand_ampl_ref_dist;
+    auto ref_dist = _conf.renderer_params.get<float>(
+        "amplitude_reference_distance");  // throws on error!
 
     xpath_result
       = scene_file->eval_xpath("//scene_setup/amplitude_reference_distance");
@@ -853,7 +844,7 @@ Controller<Renderer>::load_scene(const std::string& scene_file_name)
     // always use default value when nothing is specified
     VERBOSE("Setting amplitude reference distance to "
         << ref_dist << " meters.");
-    _scene.set_amplitude_reference_distance(ref_dist);
+    this->set_amplitude_reference_distance(ref_dist);
 
     // LOAD REFERENCE
 
@@ -1006,7 +997,8 @@ Controller<Renderer>::_create_spontaneous_scene(const std::string& audio_file_na
 
   // set master volume
   this->set_master_volume(apf::math::dB2linear(-6.0f));
-  this->set_amplitude_reference_distance(_conf.stand_ampl_ref_dist);
+  this->set_amplitude_reference_distance(_conf.renderer_params.get<float>(
+        "amplitude_reference_distance"));  // throws on error!
   // set reference
   this->set_reference_position(Position());
   this->set_reference_orientation(Orientation(90.0f));
@@ -1370,8 +1362,8 @@ Controller<Renderer>::new_source(const std::string& name
   }
 
   apf::parameter_map p;
-  p["connect_to"] = port_name;
-  p["properties_file"] = properties_file;
+  p.set("connect_to", port_name);
+  p.set("properties_file", properties_file);
   id_t id;
 
   try
